# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['router_log_preprocessor',
 'router_log_preprocessor.domain',
 'router_log_preprocessor.hooks',
 'router_log_preprocessor.hooks.zabbix',
 'router_log_preprocessor.log_server',
 'router_log_preprocessor.preprocessors',
 'router_log_preprocessor.util']

package_data = \
{'': ['*']}

install_requires = \
['anyio>=3.6.2,<4.0.0',
 'asyncio-zabbix-sender>=0.1.2,<0.2.0',
 'macaddress>=2.0.2,<3.0.0',
 'pydantic[dotenv]>=1.10.4,<2.0.0']

entry_points = \
{'console_scripts': ['router-log-preprocessor = '
                     'router_log_preprocessor.__main__:main']}

setup_kwargs = {
    'name': 'router-log-preprocessor',
    'version': '0.1.5',
    'description': '',
    'long_description': '# Router Log Preprocessor\n![router-log-preprocessor](https://user-images.githubusercontent.com/105678820/228938795-66dbd955-813b-4fb3-a559-4f3a41f55bb9.png)\n\n> Garbage in, garbage out\n>\n> &mdash; <cite>George Fuechsel</cite>\n\nPreprocessors upcycle garbage input data into well-structured data to ensure reliable and accurate event handling in third-party systems such as Zabbix.\nBy parsing and filtering the input log data, the preprocessor helps to ensure that only high-quality data are sent for further analysis and alerting.\nThis helps to minimize false positives and ensure that network administrators receive reliable and actionable alerts about potential security threats or other issues.\n\n\nKey features:\n- **Wireless LAN Controller event** log entries are parsed to tangible enumerations\n- **DNSMASQ DHCP** log entries are parsed to catch which IP a given client is assigned to\n- **Zabbix** templates are included to ensure that the logs are can lead to actionable alerts\n- **Extendable** preprocessors and hooks to ensure future reliable information to network administrators\n\n## Installation\n```console\n$ pip install router-log-preprocessor\n```\n\nIf needed it can also be installed from sources.\nRequires [Poetry 1.3.2](https://python-poetry.org/).\n```console\n$ git pull https://github.com/mastdi/router-log-preprocessor.git\n$ cd router-log-preprocessor\n$ poetry install\n```\n\n## Usage\nInstalling the package using pip also creates the executable script named `router-log-preprocessor`.\nOn Linux systems the router log preprocessor can be run by\n\n```console\n./router-log-preprocessor\n```\n\nThe configuration solely happens through environment variables or a `.env` configuration file located in the current working directory.\nThe most important variables are documented below. \nA full sample can be found in [.env](https://raw.githubusercontent.com/mastdi/router-log-preprocessor/master/.env).\nThe application reads, in order of the least priority to the highest file:\n1. `.env`,\n2. `.env.dev`,\n3. `.env.test`,\n4. `.env.staging`,\n5. `.env.prod`,\n\nmeaning that values stored in `.env.prod` will overwrite any values from other dovenv files.\nParameters stored in environment variables will always take priority over values loaded from a dotenv file.\n\n```dotenv\n# Purpose: Specifies the IP address or hostname of the local interface to which the\n# logging system should bind.\n# Format: A string containing a valid IP address or hostname, such as "192.168.0.1" or\n# "example.com".\nLOG_SERVER_HOST="0.0.0.0"\n\n# Purpose: Specifies the port number of the server to which log data should be sent.\n# Format: An integer representing a valid port number, such as 514.\nLOG_SERVER_PORT=8514\n\n# Purpose: Specifies the hostname or IP address of the Zabbix server to which the\n# Zabbix Sender should send monitoring data.\n# Format: A string containing a valid hostname or IP address, such as "example.com" or\n# "192.168.0.1".\nZABBIX_HOST="example.com"\n\n# Purpose: Specifies the port number on which the Zabbix server is running and to\n# which the Zabbix Sender should send monitoring data.\n# Format: An integer representing a valid port number, such as 10051.\nZABBIX_PORT=10051\n```\n\n## As a service\n\nThis part will go through the steps to set up the Router Log Preprocessor as a service on Ubuntu.\nThe following steps will be explained in details below:\n\n- Create a service user\n- Create a virtual environment\n- Configure environment variables\n- Set up the logging directory\n- Create the service file\n- Start the service and check its status\n- Debugging the service using journalctl\n\n### Prerequisites\n\nTo install and set up the Router Log Preprocessor as a service on Ubuntu, you will need:\n\n- Python 3.8 installed or higher\n- `venv` package (can be installed via `apt-get install python3-venv` command)\n- `pip` package manager (should be included after activating the virtual environment)\n- Internet connection to download the Router Log Preprocessor package from PyPI and the `.env` file from the GitHub repository\n\nNote that some of these prerequisites may already be installed on your Ubuntu system.\nYou can check if Python and pip are installed by running the following commands:\n\n```console\npython3 --version\npip --version\n```\n\nIf both of these commands return the version number of Python and pip, respectively, you\'re good to go.\nOtherwise, you will need to install Python and pip on your Ubuntu system before proceeding.\n\n### Creating a service user\n\nFirst, we will create a service user to run the Router Log Preprocessor.\nThis is a good security practice as running the script as a root user is not needed.\n\nRun the following commands to create a new user called `rlp`:\n\n```console\nsudo adduser rlp --disabled-password --gecos ""\nsudo su rlp\ncd ~\n```\n\nThe first command creates a new user called `rlp` with a disabled password and no additional information. \nThe second command switches to the new user and moves to their home directory.\n\n### Creating a virtual environment\n\nNow that we have a service user set up, we can create a virtual environment to install the Router Log Preprocessor.\nThe following commands create a virtual environment using Python 3.8 and install the Router Log Preprocessor package:\n\n```console\npython3 -m venv venv\ncd venv\nsource bin/activate\npip install router-log-preprocessor\n```\n\nThese commands create a new virtual environment in the venv directory, activate the environment, and install the Router Log Preprocessor package.\n\n### Configuring the environment variables \nWe will create a .env file in the virtual environment directory to store these variables.\nYou can copy the default [.env](https://raw.githubusercontent.com/mastdi/router-log-preprocessor/master/.env) file from the Router Log Preprocessor repository and customize it according to your needs:\n```console\ncurl -o .env https://raw.githubusercontent.com/mastdi/router-log-preprocessor/master/.env\nnano .env\n```\nThis will download the .env file from the Router Log Preprocessor repository and open it in the Nano text editor. \nCustomize the file to set the environment variables you need.\n\nWe are done setting up the servie user:\n\n```console\nexit\n```\n\n### Setting up the logging directory\n\nIf you have set the `LOGGING_DIRECTORY` variable in the .env file to `/var/log/rlp`, you need to create the directory and set the ownership to the rlp user:\n\n```console\nsudo mkdir /var/log/rlp\nsudo chown rlp:rlp /var/log/rlp\n```\n\nThese commands will create the `/var/log/rlp` directory and set the ownership to the `rlp` user.\n\n### Creating the service file\n\nThe next step is to create a service file for the Router Log Preprocessor.\nThis file specifies how the service should be started and managed by the system.\nCreate a new file called rlp.service in the /etc/systemd/system/ directory using the following command:\n\n```console\nsudo nano /etc/systemd/system/rlp.service\n```\n\nThis will open the text editor with a new file.\nCopy the following text into the file:\n\n```ini\n[Unit]\nDescription=Router Log Preprocessor service\nAfter=network.target\n\n[Service]\nUser=rlp\nWorkingDirectory=/home/rlp/venv\nEnvironment="PATH=/home/rlp/venv/bin"\nEnvironmentFile=/home/rlp/venv/.env\nExecStart=/home/rlp/venv/bin/router-log-preprocessor\nRestart=on-failure\nRestartSec=5s\nStartLimitInterval=60s\nStartLimitBurst=3\n\n[Install]\nWantedBy=multi-user.target\n```\n\n\n### Starting the service\n\nThe service is now ready to be started.\nThe final step is to start the service, check if it is running, and ensuring that the service starts automatically on system boot.\nStart the service using the following command:\n```console\nsudo systemctl start rlp.service\n```\n\nThis starts the service based on the configuration we just provided.\nCheck that the service is started using the following command:\n\n```console\nsudo systemctl status rlp.service\n```\n\nThis should show `active (running)` in the console.\nTo make sure the service is started on system boot use the following command:\n\n```console\nsudo systemctl enable rlp.service \n```\n\n### Debugging the service creation\n\nTo debug any issues with the service, you can use the `journalctl` command.\nFor example, to view the logs of the `rlp` service, run the following command:\n\n```console\nsudo journalctl -u rlp.service -e\n```\n\nThis will show the logs of the `rlp` service and the `-e` flag will show the end of the logs.\nYou can use other flags like `-f` to follow the logs in real-time, `-n` to specify the number of lines to show, and `-r` to show the logs in reverse order (most recent first).\n\nIf the service crashes, you can also use the `--since` and `--until` flags to show the logs between a specific time range.\nFor example, to show the logs of the last 10 minutes, run the following command:\n\n```console\nsudo journalctl -u rlp.service --since "10 minutes ago"\n```\nThis will show the logs of the `rlp` service that were generated in the last 10 minutes.\nUse this command to debug any issues with the service.',
    'author': 'Martin Storgaard Dieu',
    'author_email': 'martin@storgaarddieu.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/mastdi/router-log-preprocessor',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
